@@ -59,9 +59,11 @@ fn main() {
 
     let config = matches.value_of("config").unwrap_or("~/.taskrc");
     let report = matches.value_of("report").unwrap_or("next");
-    task::block_on(tui_main(config, report)).expect(
-        "[taskwarrior-tui error]. If you need additional help, please report as a github issue on https://github.com/kdheepak/taskwarrior-tui",
-    );
+    let r = task::block_on(tui_main(config, report));
+    if let Err(err) = r {
+        eprintln!("\x1b[0;31m[taskwarrior-tui error]\x1b[0m: {}\n\nIf you need additional help, please report as a github issue on https://github.com/kdheepak/taskwarrior-tui", err);
+        std::process::exit(1);
+    }
 }
 
 async fn tui_main(_config: &str, report: &str) -> Result<()> {
@@ -91,13 +93,36 @@ async fn tui_main(_config: &str, report: &str) -> Result<()> {
         // Handle input
         match events.next().await? {
             Event::Input(input) => {
-                if input == app.keyconfig.edit && app.mode == AppMode::TaskReport {
+                if (input == app.keyconfig.edit
+                    || input == app.keyconfig.shortcut1
+                    || input == app.keyconfig.shortcut2
+                    || input == app.keyconfig.shortcut3
+                    || input == app.keyconfig.shortcut4
+                    || input == app.keyconfig.shortcut5
+                    || input == app.keyconfig.shortcut6
+                    || input == app.keyconfig.shortcut7
+                    || input == app.keyconfig.shortcut8
+                    || input == app.keyconfig.shortcut9)
+                    && app.mode == AppMode::TaskReport
+                {
                     events.leave_tui_mode(&mut terminal);
                 }
 
                 let r = app.handle_input(input);
 
-                if input == app.keyconfig.edit && app.mode == AppMode::TaskReport {
+                if (input == app.keyconfig.edit
+                    || input == app.keyconfig.shortcut1
+                    || input == app.keyconfig.shortcut2
+                    || input == app.keyconfig.shortcut3
+                    || input == app.keyconfig.shortcut4
+                    || input == app.keyconfig.shortcut5
+                    || input == app.keyconfig.shortcut6
+                    || input == app.keyconfig.shortcut7
+                    || input == app.keyconfig.shortcut8
+                    || input == app.keyconfig.shortcut9)
+                    && app.mode == AppMode::TaskReport
+                    || app.mode == AppMode::TaskError
+                {
                     events.enter_tui_mode(&mut terminal);
                 }
                 if r.is_err() {
